# su6-plugin-svelte-check

Plugin for [su6](https://github.com/trialandsuccess/su6) that adds `svelte-check` functionality.

## License

`su6-plugin-svelte-check` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
